#include <boost/math/special_functions/erf.hpp>
#include "../boostmath/macros.hpp"

UNARY_BOOST_FUNCTION(erf, double);
UNARY_BOOST_FUNCTION(erfc, double);
UNARY_BOOST_FUNCTION(erf_inv, double);
UNARY_BOOST_FUNCTION(erfc_inv, double);
